# SMQTK - Data Providers

## Intent
This package builds on top of SMQTK-Core to provide data structures that are
abstractions around data and where it is fundamentally stored.

## Documentation
You can build the sphinx documentation locally for the most up-to-date
reference:
```bash
# Install dependencies
poetry install
# Navigate to the documentation root.
cd docs
# Build the docs.
poetry run make html
# Open in your favorite browser!
firefox _build/html/index.html
```
